@@ -138,11 +138,11 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 51200);
 
-//@line 142 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 142 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 145 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 145 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 147 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 147 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -155,14 +155,14 @@ pref("gfx.color_management.rendering_intent", 0);
 
 pref("gfx.downloadable_fonts.enabled", true);
 pref("gfx.downloadable_fonts.sanitize", true);
-//@line 162 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 162 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 pref("gfx.downloadable_fonts.sanitize.preserve_otl_tables", true);
-//@line 164 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 164 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 169 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 169 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -175,7 +175,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 185 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 185 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -523,9 +523,9 @@ pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
 pref("content.sink.event_probe_rate", 3);
-//@line 533 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 533 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 535 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 535 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -570,7 +570,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 582 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 582 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -701,6 +701,7 @@ pref("network.IDN.whitelist.es", true);
 pref("network.IDN.whitelist.fi", true);
 pref("network.IDN.whitelist.gr", true);
 pref("network.IDN.whitelist.hu", true);
+pref("network.IDN.whitelist.il", true);
 pref("network.IDN.whitelist.io", true);
 pref("network.IDN.whitelist.ir", true);
 pref("network.IDN.whitelist.is", true);
@@ -719,6 +720,7 @@ pref("network.IDN.whitelist.sh", true);
 pref("network.IDN.whitelist.th", true);
 pref("network.IDN.whitelist.tm", true);
 pref("network.IDN.whitelist.tw", true);
+pref("network.IDN.whitelist.ua", true);
 pref("network.IDN.whitelist.vn", true);
 
 // IDN ccTLDs
@@ -727,6 +729,8 @@ pref("network.IDN.whitelist.xn--mgbaam7a8h", true);
 // cn, China, .<China> with variants
 pref("network.IDN.whitelist.xn--fiqz9s", true); // Traditional
 pref("network.IDN.whitelist.xn--fiqs8s", true); // Simplified
+// eg, Egypt, .<Masr>
+pref("network.IDN.whitelist.xn--wgbh1c", true);
 // hk, Hong Kong, .<Hong Kong>
 pref("network.IDN.whitelist.xn--j6w193g", true);
 // ir, Iran, <.Iran> with variants
@@ -734,6 +738,8 @@ pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
 pref("network.IDN.whitelist.xn--mgba3a4fra", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+// qa, Qatar, .<Qatar>
+pref("network.IDN.whitelist.xn--wgbl6a", true);
 // ru, Russian Federation, .<RF>
 pref("network.IDN.whitelist.xn--p1ai", true);
 // sa, Saudi Arabia, .<al-Saudiah> with variants
@@ -831,7 +837,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 848 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 854 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -850,9 +856,9 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 868 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 874 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 875 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 881 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1214,15 +1220,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1615 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 1621 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 
-//@line 2032 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 2038 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 
-//@line 2233 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 2239 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 
-//@line 2327 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 2333 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 
-//@line 2330 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 2336 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1490,15 +1496,15 @@ pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER
 // So, we have no reasons we should use non-toplevel window for popup.
 pref("ui.panel.default_level_parent", true);
 
-//@line 2600 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 2606 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 
-//@line 2668 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 2674 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 
-//@line 2694 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 2700 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 
-//@line 2714 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 2720 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 
-//@line 2722 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 2728 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1522,7 +1528,7 @@ pref("image.cache.size", 5242880);
 // Size is given a weight of 1000 - timeweight.
 pref("image.cache.timeweight", 500);
 
-//@line 2751 "/usr/obj/i386/firefox35-3.5.16/mozilla-1.9.1/modules/libpref/src/init/all.js"
+//@line 2757 "/usr/obj/firefox35-3.5.19/mozilla-1.9.1/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
